pub(crate) enum SessionIntent {
ShowMatrixId(MatrixIdUri),
ShowIdentityVerification(VerificationKey),
}Expand description
Intents that can be handled by a session.
It cannot be cloned intentionally, so it is handled only once.
Variants
ShowMatrixId(MatrixIdUri)
Show the target of a Matrix ID URI.
ShowIdentityVerification(VerificationKey)
Show an ongoing identity verification.
Implementations
Sourceimpl SessionIntent
impl SessionIntent
Sourcepub(crate) const SHOW_MATRIX_ID_APP_ACTION_NAME: &str = "app.show-matrix-id"
pub(crate) const SHOW_MATRIX_ID_APP_ACTION_NAME: &str = "app.show-matrix-id"
The application action name for the SessionIntent::ShowMatrixId
variant.
Sourcepub(crate) const SHOW_MATRIX_ID_ACTION_NAME: &str
pub(crate) const SHOW_MATRIX_ID_ACTION_NAME: &str
The action name without the app. prefix for the
SessionIntent::ShowMatrixId variant.
Sourcepub(crate) const SHOW_IDENTITY_VERIFICATION_APP_ACTION_NAME: &str = "app.show-identity-verification"
pub(crate) const SHOW_IDENTITY_VERIFICATION_APP_ACTION_NAME: &str = "app.show-identity-verification"
The application action name for the
SessionIntent::ShowIdentityVerification variant.
Sourcepub(crate) const SHOW_IDENTITY_VERIFICATION_ACTION_NAME: &str
pub(crate) const SHOW_IDENTITY_VERIFICATION_ACTION_NAME: &str
The action name without the app. prefix for the
SessionIntent::ShowIdentityVerification variant.
Sourcepub(crate) fn app_action_name(&self) -> &'static str
pub(crate) fn app_action_name(&self) -> &'static str
Get the application action name for this session intent type.
Sourcepub(crate) fn show_matrix_id_from_variant(
variant: &Variant,
) -> Option<(String, Self)>
pub(crate) fn show_matrix_id_from_variant( variant: &Variant, ) -> Option<(String, Self)>
Convert the given GVariant to a SessionIntent::ShowMatrixId and
session ID, given the intent type.
Returns a (session_id, intent) tuple on success. Returns None if
the GVariant could not be parsed successfully.
Sourcepub(crate) fn show_identity_verification_from_variant(
variant: &Variant,
) -> Option<(String, Self)>
pub(crate) fn show_identity_verification_from_variant( variant: &Variant, ) -> Option<(String, Self)>
Convert the given GVariant to a
SessionIntent::ShowIdentityVerification and session ID, given the
intent type.
Returns a (session_id, intent) tuple on success. Returns None if
the GVariant could not be parsed successfully.
Sourcepub(crate) fn to_variant_with_session_id(&self, session_id: String) -> Variant
pub(crate) fn to_variant_with_session_id(&self, session_id: String) -> Variant
Convert this intent to a GVariant with the given session ID.